.. _all-salt.queues:

===========================
Full list of builtin queues
===========================

.. currentmodule:: salt.queues

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    sqlite_queue
